Description: Lists all of the available service-specific resources, actions, and condition keys that can be used in IAM policies to control access to AWS Trusted Advisor.

Actions, resources, and condition keys for AWS Trusted Advisor - Service Authorization Reference

# Actions, resources, and condition keys for AWS Trusted Advisor

AWS Trusted Advisor (service prefix: `trustedadvisor` ) provides the following service-specific resources, actions, and condition context keys for use in IAM permission policies.

References:

- Learn how to configure this service .

- View a list of the API operations available for this service .

- Learn how to secure this service and its resources by using IAM permission policies.

Topics

- Actions defined by AWS Trusted Advisor
- Resource types defined by AWS Trusted Advisor
- Condition keys for AWS Trusted Advisor

## Actions defined by AWS Trusted Advisor

You can specify the following actions in the `Action` element of an IAM policy statement. Use policies to grant permissions to perform an operation in AWS. When you use an action in a policy, you usually allow or deny access to the API operation or CLI command with the same name. However, in some cases, a single action controls access to more than one operation. Alternatively, some operations require several different actions.

The Resource types column indicates whether each action supports resource-level permissions. If there is no value for this column, you must specify all resources ("*") in the `Resource` element of your policy statement. If the column includes a resource type, then you can specify an ARN of that type in a statement with that action. Required resources are indicated in the table with an asterisk (*). If you specify a resource-level permission ARN in a statement using this action, then it must be of this type. Some actions support multiple resource types. If the resource type is optional (not indicated as required), then you can choose to use one but not the other.

For details about the columns in the following table, see Actions table .

Note

The IAM Trusted Advisor policy description details apply only to the Trusted Advisor console. If you want to manage programmatic access to Trusted Advisor, use the Trusted Advisor operations in the AWS Support API.

Actions | Description | Access level | Resource types (*required) | Condition keys | Dependent actions
--- | --- | --- | --- | --- | ---
DescribeAccount [permission only] | Grants permission to view the AWS Support plan and various AWS Trusted Advisor preferences | Read |  |  |
DescribeAccountAccess [permission only] | Grants permission to view if the AWS account has enabled or disabled AWS Trusted Advisor | Read |  |  |
DescribeCheckItems | Grants permission to view details for the check items | Read | checks* |  |
DescribeCheckRefreshStatuses | Grants permission to view the refresh statuses for AWS Trusted Advisor checks | Read | checks* |  |
DescribeCheckSummaries | Grants permission to view AWS Trusted Advisor check summaries | Read | checks* |  |
DescribeChecks | Grants permission to view details for AWS Trusted Advisor checks | Read |  |  |
DescribeNotificationPreferences [permission only] | Grants permission to view the notification preferences for the AWS account | Read |  |  |
DescribeOrganization [permission only] | Grants permission to view if the AWS account meets the requirements to enable the organizational view feature | Read |  |  |
DescribeOrganizationAccounts [permission only] | Grants permission to view the linked AWS accounts that are in the organization | Read |  |  |
DescribeReports [permission only] | Grants permission to view details for organizational view reports, such as the report name, runtime, date created, status, and format | Read |  |  |
DescribeRisk | Grants permission to view risk details in AWS Trusted Advisor Priority | Read |  |  |
DescribeRiskResources | Grants permission to view affected resources for a risk in AWS Trusted Advisor Priority | Read |  |  |
DescribeRisks | Grants permission to view risks in AWS Trusted Advisor Priority | Read |  |  |
DescribeServiceMetadata [permission only] | Grants permission to view information about organizational view reports, such as the AWS Regions, check categories, check names, and resource statuses | Read |  |  |
DownloadRisk | Grants permission to download a file that contains details about the risk in AWS Trusted Advisor Priority | Read |  |  |
ExcludeCheckItems [permission only] | Grants permission to exclude recommendations for AWS Trusted Advisor checks | Write | checks* |  |
GenerateReport [permission only] | Grants permission to create a report for AWS Trusted Advisor checks in your organization | Write |  |  |
IncludeCheckItems [permission only] | Grants permission to include recommendations for AWS Trusted Advisor checks | Write | checks* |  |
ListAccountsForParent [permission only] | Grants permission to view, in the Trusted Advisor console, all of the accounts in an AWS organization that are contained by a root or organizational unit (OU) | Read |  |  |
ListOrganizationalUnitsForParent [permission only] | Grants permission to view, in the Trusted Advisor console, all of the organizational units (OUs) in a parent organizational unit or root | Read |  |  |
ListRoots [permission only] | Grants permission to view, in the Trusted Advisor console, all of the roots that are defined in an AWS organization | Read |  |  |
RefreshCheck | Grants permission to refresh an AWS Trusted Advisor check | Write | checks* |  |
SetAccountAccess [permission only] | Grants permission to enable or disable AWS Trusted Advisor for the account | Write |  |  |
SetOrganizationAccess [permission only] | Grants permission to enable the organizational view feature for AWS Trusted Advisor | Write |  |  |
UpdateNotificationPreferences [permission only] | Grants permission to update notification preferences for AWS Trusted Advisor | Write |  |  |
UpdateRiskStatus | Grants permission to update the risk status in AWS Trusted Advisor Priority | Write |  |  |

## Resource types defined by AWS Trusted Advisor

The following resource types are defined by this service and can be used in the `Resource` element of IAM permission policy statements. Each action in the Actions table identifies the resource types that can be specified with that action. A resource type can also define which condition keys you can include in a policy. These keys are displayed in the last column of the table. For details about the columns in the following table, see Resource types table .

Resource types | ARN | Condition keys
--- | --- | ---
checks | `arn:$ { Partition}:trustedadvisor:$ { Region}:$ { Account}:checks/$ { CategoryCode}/$ { CheckId}` |

## Condition keys for AWS Trusted Advisor

Trusted Advisor has no service-specific context keys that can be used in the `Condition` element of policy statements. For the list of the global context keys that are available to all services, see Available keys for conditions .

Did this page help you? - Yes

Thanks for letting us know we're doing a good job!

If you've got a moment, please tell us what we did right so we can do more of it.

Did this page help you? - No

Thanks for letting us know this page needs work. We're sorry we let you down.

If you've got a moment, please tell us how we can make the documentation better.